#! /bin/sh
#
#  activate_swap.sh

# first swapoff any already activated swap device
SWAP_DEV=`fdisk -l | grep "Linux swap" | cut -c 1-10`
for device in $SWAP_DEV
do
    swapoff $device 2>/dev/null
done

# There is probably a better way to do this.
# We don't have access to dmesg, and a limited tool set.
num=`fdisk -l | grep -c Linux`
swap_num=`fdisk -l | grep -c swap`
echo
echo "I found $num Linux partitions, $swap_num of which"
echo "is defined as swap space."

# Make sure we have swap space.
if [ "$swap_num" -eq "0" ]; then
    echo "No swap device? Please try again and remember to set"
    echo "the file system type of the swap device to 'linux swap'"
    echo "Exiting..."
    echo hit ENTER
    read x
    exit
fi

# Make sure we have at least 2 partitions.
if [ "$num" -lt "2" ]; then
    echo "Only $num partitions? Please try again and remember"
    echo "you need one swap partition and at least one other"
    echo "Linux partition for your file system."
    echo "Exiting..."
    echo hit ENTER
    read x
    exit
fi

# Create file systems
# Locate the swap partition(s), create and activate swap.
SWAP_DEV=`fdisk -l | grep "Linux swap" | cut -c 1-10`
export SWAP_DEV
echo SWAP_DEV=$SWAP_DEV >> $install_log
for device in $SWAP_DEV
do
    echo "Making swap file system on $device"
    dialog --defaultno --colors --yesno "
    It is suggested that you activate the swap partition
    at device '$device'.
\Z1    
                     *************
                     * Attention *
                     *************

    But -!- this will erase the contents of this partition,
    no way to get it back later.
\Zn
    Activate swap at [ $device ] now ?
" 18 70
    [ $? -eq 0 ] && answer=yes || answer=no
    if [ "$answer" = 'yes' ]; then
	mkswap -v1 $device > /dev/null 2>&1 || {
	    echo "mkswap failed, exiting, hit ENTER"; read x
	    exit
	}

	echo "Activating swap partition."
	swapon $device > /dev/null 2>&1 || {
	    echo "swapon failed, exiting, hit ENTER"; read x
	    exit
	}
	sleep 5
    else
	echo "Swap at device '$device' NOT activated, hit ENTER"; read x
    fi
done

# echo hit ENTER; read x