#!/bin/sh

# Copyright (C) 2002 Michael Fratoni
# <Devon@tuxfan.homeip.net>
# Copyright (C) The "RULE" project
# http://www.rule-project.org/

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# The GNU General Public License is also available online:
# http://www.gnu.org/licenses/gpl.html

#############################################################################

# set -x

# This script creates and mounts the install partitions,
# and determines the install method.
# It then executes a pivot_root, and chroot, to give us
# Access to our new / directory.

# Slinky can use a configuration file. To use this feature,
# edit /scripts/slinky.config.sample and save it as
# /scripts/slinky.config. Use caution, this removes much
# of the interactive nature of the installer. For example
# if you point the config file at your windows partition,
# It will happily format the partition for you.

if [ -f "/scripts/slinky.config" ]; then
    echo "Configuration file exists:" >> $install_log
    echo "==============================================" >> $install_log
    cat /scripts/slinky.config >> $install_log
    echo "==============================================" >> $install_log
    echo "End configuration file." >> $install_log

    # Source the config file.
    . /scripts/slinky.config
fi

. /scripts/pre_install.sh

# If we are here, we want to continue. Say hello, define the drives, and
# begin logging.
echo `date` Slinky installer starting. >> $install_log
echo Command line used: >> $install_log
echo `cat /proc/cmdline` >> $install_log
echo Processor info: >> $install_log
echo `head -n5 /proc/cpuinfo` >> $install_log
echo Memory info: >> $install_log
echo `head -n5 /proc/meminfo` >> $install_log

dialog --no-collapse --msgbox '
     **********************************************************
     *   Welcome to "Slinky" the RULE low memory installer!   *
     **********************************************************

     NOTE: When prompted for an answer, the value in upper case
     is the default. (if there is a default value.) Please
     answer all questions in lower case.

     If the screen should "blank" due to inactivity, DO NOT hit
     the <ENTER> key.

     Please use the <BACKSPACE>- or <SHIFT>-key instead.
' 20 70

dialog --no-collapse --msgbox '
     You can remove the boot-floppy now and use the drive later
     to load modules if you need them.
' 10 70

cat >/scripts/menu_list.txt <<EOF
/scripts/select_keymap.sh      Select_the_keyboard_layout
/scripts/select_distri.sh      Select_the_distribution_to_install
/scripts/select_method.sh      Select_your_installation_method
/scripts/select_fstype.sh      Select_the_filesystem_type_to_use
/scripts/select_instdev.sh     Select_where_to_install_FC${version}
/scripts/do_partitioning.sh    Partition_the_harddisk(s)
/scripts/activate_swap.sh      Activate_swap
/scripts/format_mount.sh       Format_and_mount_partitions
/scripts/prepare_newroot.sh    Prepare_the_new_root-partition
/scripts/in_newroot.sh    bootstrap_rpm.sh In_newroot_context:make_full_featured_rpm
/scripts/in_newroot.sh    base_install.sh  In_newroot_context:Install_FC${version}
/scripts/in_newroot.sh    config_new.sh    In_newroot_context:Set_hostname_and_users
/scripts/in_newroot.sh    grub_install.sh  In_newroot_context:Install_bootloader_GRUB
/scripts/in_newroot.sh    mk_bootfloppy.sh In_newroot_context:Create_bootfloppy
/scripts/initial_reboot.sh     Reboot
/scripts/in_newroot.sh    sh_newroot.sh    In_newroot_context:Drop_to_a_shell
/scripts/sh_oldroot.sh         Drop_to_a_shell
EOF

awk 'NF==2 {print ++i " " $1}
     NF==3 {print ++i " " $1 " " $2}' /scripts/menu_list.txt >/scripts/menu_scripts.txt

awk '{print ++i " " $NF}' /scripts/menu_list.txt >/scripts/menu_text.txt

next_step=1
while :; do

dialog --no-collapse --no-cancel --backtitle "SLINKY installation of FC${version}" --menu "
    To go thru all steps select 'OK' until you reach reboot.

    You can allways change order of processing by selecting
    your favorite next step.  Usually it dosn't make sense to do
    the second step before the first - but YMMV.

    Next we suggest to do:
" 20 70 5 `grep "^$next_step " /scripts/menu_text.txt` '' '' `grep -v "^$next_step " /scripts/menu_text.txt` 2>/tmp/dialog.inp
next_step=`cat /tmp/dialog.inp`

. `grep "^$next_step " /scripts/menu_scripts.txt | cut -d' ' -f2-`

next_step=`expr $next_step + 1`

done
